#
# spec file for package python-sympy
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-sympy
Version:        0.7.5
Release:        8.5
Summary:        Python library for symbolic mathematics
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://code.google.com/p/sympy/
Source0:        https://pypi.python.org/packages/source/s/sympy/sympy-%{version}.tar.gz
BuildRequires:  python-devel >= 2.5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%else
BuildArch:      noarch
%endif

%description
SymPy is a Python library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python and does not require
any external libraries.

%prep
%setup -q -n sympy-%{version}
# For rpmlint warning: remove shebang from python library:
sed -i '/^#!/d' ./sympy/mpmath/tests/runtests.py

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --prefix=%{_prefix}
mv %{buildroot}%{_bindir}/isympy %{buildroot}%{_bindir}/isympy-%{py_ver}
ln -s %{_bindir}/isympy-%{py_ver} %{buildroot}%{_bindir}/isympy
mv %{buildroot}%{_mandir}/man1/isympy.1 %{buildroot}%{_mandir}/man1/isympy-%{py_ver}.1
ln -s %{_mandir}/man1/isympy-%{py_ver}.1 %{buildroot}%{_mandir}/man1/isympy.1

%pre
# Since /usr/bin/isympy and /usr/share/man/man1/isympy.1.gz became ghosted to be used
# with update-alternatives, we have to get rid of the old binary resulting from the
# non-update-alternativies-ified package:
[ -h %{_bindir}/isympy ] || rm -f %{_bindir}/isympy
[ -h %{_mandir}/man1/isympy.1.gz ] || rm -f %{_mandir}/man1/isympy.1.gz

%post
update-alternatives \
    --install %{_bindir}/isympy isympy %{_bindir}/isympy-%{py_ver} 20 \
    --slave %{_mandir}/man1/isympy.1.gz isympy.1 %{_mandir}/man1/isympy-%{py_ver}.1.gz

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove isympy %{_bindir}/isympy-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%ghost %{_bindir}/isympy
%{_bindir}/isympy-%{py_ver}
%ghost %{_mandir}/man1/isympy.1.gz
%{_mandir}/man1/isympy-%{py_ver}.1.gz
%{python_sitelib}/sympy
%{python_sitelib}/sympy-%{version}-py%{py_ver}.egg-info

%changelog
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Fri Mar  7 2014 arun@gmx.de
-  update to version 0.7.5
  Major changes:
  * The version of mpmath included in SymPy has been updated to 0.18.
  * New routines for efficiently compute the dispersion of a polynomial or a pair thereof.
  * Fancy indexing of matrices is now provided, e.g. A[:, [1, 2, 5]] selects all rows and only 3 columns.
  * Enumeration of multiset partitions is now based on an
    implementation of Algorithm 7.1.2.5M from Knuth's The Art of
    Computer Programming. The new version is much faster, and includes
    fast methods for enumerating only those partitions with a
    restricted range of sizes, and counting multiset partitions. (See
    the new file sympy.utilities.enumerative.py.)
  * distance methods were added to Line and Ray to compute the shortest distance to them from a point.
  * The normal_lines method was added to Ellipse to compute the lines from a point that strike the Ellipse at a normal angle.
  * inv_quick and det_quick were added as functions in solvers.py to
    facilitate fast solution of small symbolic matrices; their use in
    solve has reduced greatly the time needed to solve such systems.
  * solve_univariate_inequality has been added to sympy.solvers.inequalities.py.
  * as_set attribute for Relationals and Booleans has been added.
  * Several classes and functions strictly associated with vector
    calculus were moved from sympy.physics.mechanics to a new package
    sympy.physics.vector. (PRs #2732 #2862 #2894)
  * New implementation of the Airy functions Ai and Bi and their
    derivatives Ai' and Bi' (called airyai, airybi, airyaiprime and
    airybiprime, respectively). Most of the usual features of SymPy
    special function are present. Notable exceptions are Gruntz limit
    computation helpers and meijerg special functions integration
    code.
  * Euler-Lagrange equations (function euler_equations) in a new package sympy.calculus (PR #2431).
  Minor changes:
  * Some improvements to the gamma function.
  * generate_bell now generates correct permutations for any number of elements.
  * It is no longer necessary to provide nargs to objects subclassed
    from Function unless an eval class method is not defined. (If eval
    is defined, the number of arguments will be inferred from its
    signature.)
  * geometric Point creation will be faster since simplification is done only on Floats
  * Some improvements to the intersection method of the Ellipse.
  * solutions from solve of equations involving multiple log terms are more robust
  * idiff can now return higher order derivatives
  * Added to_matrix() method to sympy.physics.vector.Vector and
    sympy.physics.dyadic.Dyadic. (PR #2686).
  * Printing improvements for sympy.physics.vector objects and
    mechanics printing. (PRs #2687, #2728, #2772, #2862, #2894)
  * Functions with LaTeX symbols now print correct LaTeX. (PR #2772)
  * init_printing has several new options, including a flag
    print_builtin to prevent SymPy printing of basic Python types (PR
    [#2683]), and flags to let you supply custom printers (PR #2894).
  * improvements in evaluation of imageset for Intervals (PR #2723).
  * Set properties to determine boundary and interior (PR #2744).
  * input to a function created by lambdify no longer needs to be flattened.
  Backwards compatibility breaks and deprecations:
  * the submatrix method of matrices was removed; access the
    functionality by providing slices or list of rows/columns to
    matrix directly, e.g. A[:, [1, 2]].
  * Matrix([]) and Matrix([[]]) now both return a 0x0 matrix
  * terms_gcd no longer removes a -1.0 from expressions
  * extract_multiplicatively will not remove a negative Number from a
    positive one, so (4*x*y).extract_multiplicatively(-2*x) will
    return None.
  * the shape of the result from M.cross(B) now has the same shape as matrix M.
  * The factorial of negative numbers is now zoo instead of 0. This is
    consistent with the definition factorial(n) = gamma(n + 1).
  * 1/0 returns zoo, not oo (PR #2813).
  * zoo.is_number is True (PR #2823).
  * oo < I raises TypeError, just as for finite numbers (PR #2734).
  * 1**oo == nan instead of 1, better documentation for Pow class (PR #2606).
* Sat Jan 11 2014 arun@gmx.de
- update to 0.7.4.1
  * This was a small bugfix release to fix an import issue on Windows (https://github.com/sympy/sympy/issues/2681).
- update to 0.7.4 (see https://github.com/sympy/sympy/wiki/Release-Notes-for-0.7.4)
* Thu Sep 26 2013 speilicke@suse.com
- Update to version 0.7.3:
  + See https://github.com/sympy/sympy/wiki/Release-Notes-for-0.7.3
- Use update-alternatives for binaries / man-pages
* Tue Jan 15 2013 p.drouand@gmail.com
- Initial python3 support
* Tue Jan 15 2013 p.drouand@gmail.com
- Update to 0.7.2 version:
  * pep8 correction: don't include space around * and **
  * radsimp watches for pure radical in denominator
  * pep8 E702: one statement per line
  * add class name to hash value
  * give more explicit error messages
  * fix quality and ode constant numbering bug
  * mprovements to euler equation solver
  * Sparse hash now includes shape
  * add hash to SparseMatrix
  * raise notimplemented on MatrixExpr.conjugate
  * removed cruft print statement
- Fix the shebang RPMLint without make python libraries executables,
  it is not the good way
* Thu Jan  3 2013 toddrme2178@gmail.com
- Fix building on SLES 11
* Thu May  3 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  Always state the exact version of the license and use SPDX syntax
  (http://www.spdx.org/licenses)
* Sat Feb 25 2012 scorot@free.fr
- fix build for SLE-11
* Sun Nov 20 2011 werner.ho@gmx.de
- new version 0.7.1
* Mon Mar 29 2010 Werner Hoch <werner.ho@gmx.de> - 0.6.7
- new version 0.6.7
* Sun Dec 20 2009 Werner Hoch <werner.ho@gmx.de> - 0.6.5
- fixed site-packages location for openSUSE 11.2
* Sun Oct  4 2009 Werner Hoch <werner.ho@gmx.de> - 0.6.5
- new version 0.6.5
* Sun Apr 19 2009 Werner Hoch <werner.ho@gmx.de> - 0.6.4
- new version 0.6.4
* Mon Nov 24 2008 Werner Hoch <werner.ho@gmx.de> - 0.6.3
- new version 0.6.3
* Sat Sep 20 2008 Werner Hoch <werner.ho@gmx.de> - 0.6.2
- fixed wrong man-page in INSTALLED_FILES list
